package be.iminds.ilabt.jfed.espec.model;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.util.Collections;
import java.util.List;
import java.util.Objects;

/**
 * FileSource
 */
public class GeneratedRSpecFileSource extends FileSource {
    @Nonnull private final String am; //urn or serverId
    @Nullable private final String resourceClass;
    private final int nodeCount;
    @Nonnull private final String nodeNamePrefix;
    @Nonnull private final List<String> nodeNames;
    @Nullable private final String diskImage;

    public GeneratedRSpecFileSource(@Nonnull SourceType sourceType, @Nonnull String value, @Nonnull String basename,
                                    @Nonnull String am, @Nullable String resourceClass,
                                    int nodeCount, @Nullable String nodeNamePrefix, @Nullable List<String> nodeNames,
                                    @Nullable String diskImage) {
       super(sourceType, value, basename);
       this.am = am;
       this.resourceClass = resourceClass;

       this.nodeNamePrefix = nodeNamePrefix == null ? "n" : nodeNamePrefix;
       this.nodeNames = nodeNames == null ? Collections.emptyList() : nodeNames;
       this.nodeCount = nodeCount;
       this.diskImage = diskImage;
    }

    @Nonnull
    public String getAm() {
        return am;
    }

    @Nullable
    public String getResourceClass() {
        return resourceClass;
    }

    public int getNodeCount() {
        return nodeCount;
    }

    @Nonnull
    public String getNodeNamePrefix() {
        return nodeNamePrefix;
    }

    @Nonnull
    public List<String> getNodeNames() {
        return nodeNames;
    }

    @Nullable
    public String getDiskImage(){
        return diskImage;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        GeneratedRSpecFileSource that = (GeneratedRSpecFileSource) o;
        return nodeCount == that.nodeCount &&
                Objects.equals(am, that.am) &&
                Objects.equals(resourceClass, that.resourceClass) &&
                Objects.equals(nodeNamePrefix, that.nodeNamePrefix) &&
                Objects.equals(nodeNames, that.nodeNames) &&
                Objects.equals(diskImage, that.diskImage);
    }

    @Override
    public int hashCode() {
        return Objects.hash(super.hashCode(), am, resourceClass, nodeCount, nodeNamePrefix, nodeNames, diskImage);
    }

    @Override
    public String toString() {
        return "GeneratedRSpecFileSource{" +
                "am='" + am + '\'' +
                ", resourceClass='" + resourceClass + '\'' +
                ", nodeCount=" + nodeCount +
                ", type=" + type +
                ", value='" + value + '\'' +
                ", basename='" + basename + '\'' +
                ", diskImage='" + diskImage + '\'' +
                '}';
    }
}
