package be.iminds.ilabt.jfed.highlevel.tasks;

import be.iminds.ilabt.jfed.highlevel.controller.Task;
import be.iminds.ilabt.jfed.highlevel.controller.TaskExecution;
import be.iminds.ilabt.jfed.highlevel.model.Slice;
import be.iminds.ilabt.jfed.lowlevel.JFedException;
import be.iminds.ilabt.jfed.lowlevel.api_wrapper.UserAndSliceApiWrapper;
import be.iminds.ilabt.jfed.util.GeniUrn;
import be.iminds.ilabt.jfed.util.JavaFXLogger;

import javax.annotation.Nonnull;
import java.util.Collections;
import java.util.List;

/**
 * User: twalcari
 * Date: 6/17/2015
 * Time: 16:25
 */
public class UnshareSliceTask extends Task {
    @Nonnull private final Slice slice;
    @Nonnull private final GeniUrn userUrn;

    @Nonnull private final UserAndSliceApiWrapper userAndSliceApiWrapper;
    @Nonnull private final JavaFXLogger logger;
    @Nonnull private final HighLevelTaskFactory highLevelTaskFactory;

    public UnshareSliceTask(@Nonnull Slice slice,
                            @Nonnull GeniUrn userUrn,
                            @Nonnull UserAndSliceApiWrapper userAndSliceApiWrapper,
                            @Nonnull JavaFXLogger logger,
                            @Nonnull HighLevelTaskFactory highLevelTaskFactory) {
        super("Unshare slice \"" + slice.getUrn().getEncodedResourceName() + "\" with " + userUrn.getEncodedResourceName());
        this.slice = slice;
        this.userUrn = userUrn;
        this.userAndSliceApiWrapper = userAndSliceApiWrapper;
        this.logger = logger;
        this.highLevelTaskFactory = highLevelTaskFactory;
    }

    @Override
    public void doTask(@Nonnull TaskExecution taskExecution) throws JFedException, InterruptedException {
        userAndSliceApiWrapper.unshareSlice(
                JavaFXLogger.wrap(logger, taskExecution),
                slice.getUrn(),
                slice.getCredentials(),
                userUrn);

        //no exception, so we can add the user
        slice.addUser(userUrn);
    }

    @Nonnull
    @Override
    public List<Task> initDependsOn() {
        return Collections.singletonList(highLevelTaskFactory.getSliceCredential(slice));
    }
}
